/// <reference types="node" />
import type { Document } from 'mongodb';
export interface EmailPasswordAuthOptions {
    email: string;
    password: string;
}
export interface ApiKeyAuthOptions {
    apiKey: string;
}
export interface CustomJwtAuthOptions {
    jwtTokenString: string;
}
export type Documents = {
    documents: Document[];
};
export type UpdateResult = {
    matchedCount: number;
    modifiedCount: number;
    upsertedId?: string;
};
export type DeleteResult = {
    deletedCount: number;
};
export type AuthOptions = EmailPasswordAuthOptions | ApiKeyAuthOptions | CustomJwtAuthOptions;
export interface MongoClientConstructorOptions {
    dataSource: string;
    auth: AuthOptions;
    endpoint: string;
}
export type MongoInsertOne = {
    dataSource: string;
    database: string;
    collection: string;
    document: Document;
};
export declare class MongoClient {
    dataSource: string;
    endpoint: string;
    fetch: typeof fetch;
    headers: import("undici-types").Headers;
    constructor({ dataSource, auth, endpoint }: MongoClientConstructorOptions);
    database(name: string): Database;
}
export declare class Database {
    name: string;
    client: MongoClient;
    constructor(name: string, client: MongoClient);
    collection<T extends Document>(name: string): Collection<T>;
}
export declare class Collection<T> {
    name: string;
    database: Database;
    client: MongoClient;
    constructor(name: string, database: Database);
    insertOne(doc: T): Promise<MongoInsertOne>;
    insertMany(docs: T[]): Promise<{
        insertedIds: string[];
    }>;
    findOne(filter: Document, { projection }?: {
        projection?: Document;
    }): Promise<Document>;
    find(filter?: Document, { projection, sort, limit, skip }?: {
        projection?: Document;
        sort?: Document;
        limit?: number;
        skip?: number;
    }): Promise<Document[]>;
    updateOne(filter: Document, update: Document, { upsert }?: {
        upsert?: boolean;
    }): Promise<UpdateResult>;
    updateMany(filter: Document, update: Document, { upsert }?: {
        upsert?: boolean;
    }): Promise<UpdateResult>;
    replaceOne(filter: Document, replacement: Document, { upsert }?: {
        upsert?: boolean;
    }): Promise<UpdateResult>;
    deleteOne(filter: Document): Promise<DeleteResult>;
    deleteMany(filter: Document): Promise<DeleteResult>;
    aggregate<T extends Document>(pipeline: Document[]): Promise<T[]>;
    countDocuments(filter?: Document, options?: {
        limit?: number;
        skip?: number;
    }): Promise<number>;
    estimatedDocumentCount(): Promise<number>;
    callApi<T>(method: string, extra: Document): Promise<T>;
}
